/*
 * @(#)src/classes/sov/java/awt/CompositeContext.java, awt, as131, 20031014 1.5.2.1
 * ===========================================================================
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 *
 * IBM Java(tm)2 SDK, Standard Edition, v 1.3.1
 * (C) Copyright IBM Corp. 1998, 2001. All Rights Reserved
 * ===========================================================================
 */

/*
 *
 * ===========================================================================
 *
 * Copyright 1997-2000 Sun Microsystems, Inc. All Rights Reserved.
 * ===========================================================================
 */
 
/*
 * @(#)CompositeContext.java	1.20 98/10/19
 *
 */

package java.awt;

import java.awt.image.Raster;
import java.awt.image.WritableRaster;

/**
 * The <code>CompositeContext</code> interface defines the encapsulated
 * and optimized environment for a compositing operation.
 * <code>CompositeContext</code> objects maintain state for
 * compositing operations.  In a multi-threaded environment, several
 * contexts can exist simultaneously for a single {@link Composite} 
 * object.
 * @see Composite
 * @version 10 Feb 1997
 */

public interface CompositeContext {
    /**
     * Releases resources allocated for a context.
     */
    public void dispose();

    /**
     * Composes the two source {@link Raster} objects and 
     * places the result in the destination 
     * {@link WritableRaster}.  Note that the destination 
     * can be the same object as either the first or second 
     * source. Note that <code>dstIn</code> and 
     * <code>dstOut</code> must be compatible with the 
     * <code>dstColorModel</code> passed to the 
     * {@link Composite#createContext(java.awt.image.ColorModel, java.awt.image.ColorModel, java.awt.RenderingHints) createContext} 
     * method of the <code>Composite</code> interface.
     * @param src the first source for the compositing operation
     * @param dstIn the second source for the compositing operation
     * @param dstOut the <code>WritableRaster</code> into which the 
     * result of the operation is stored
     * @see Composite
     */
    public void compose(Raster src,
                        Raster dstIn,
			WritableRaster dstOut);


}

